pub enum ControllerCommand {
SetAdmins {
admins: Option<Vec<AccountOwner>>,
},
RemoveWorker {
worker_id: ChainId,
},
UpdateService {
service_id: ManagedServiceId,
workers: Vec<ChainId>,
},
RemoveService {
service_id: ManagedServiceId,
},
UpdateAllServices {
services: Vec<(ManagedServiceId, Vec<ChainId>)>,
},
UpdateChain {
chain_id: ChainId,
workers: Vec<ChainId>,
},
RemoveChain {
chain_id: ChainId,
},
UpdateAllChains {
chains: Vec<(ChainId, Vec<ChainId>)>,
},
}Expand description
A controller command
Variants
SetAdmins
Set the admin owners.
Fields

admins: Option<Vec<AccountOwner>>RemoveWorker
Remove a worker. (This should not usually happen, but some workers may be broken and need to be cleaned up.)
UpdateService
Update the state of a particular service to be running on the specific workers.
RemoveService
Remove a service from the map entirely.
Fields

service_id: ManagedServiceIdUpdateAllServices
Set the states of all services at once, possibly removing some of them.
Fields

services: Vec<(ManagedServiceId, Vec<ChainId>)>UpdateChain
Update the state of a particular chain to be listened to on the specific workers.
RemoveChain
Remove a chain from the map entirely.
UpdateAllChains
Set the states of all chains at once, possibly removing some of them.