pub struct LocalWorkerState {
pub local_worker: Option<Worker>,
pub local_services: Vec<ManagedService>,
pub local_chains: Vec<ChainId>,
pub local_message_policy: BTreeMap<ChainId, MessagePolicy>,
}Expand description
The local state of a worker.
Fields
local_worker: Option<Worker>The description of this worker as we registered it.
local_services: Vec<ManagedService>The services currently running locally.
local_chains: Vec<ChainId>The chains currently followed locally (besides ours and the active service chains).
local_message_policy: BTreeMap<ChainId, MessagePolicy>The message policy that should be followed by the worker.