pub struct ManagedService {
pub application_id: ApplicationId,
pub name: String,
pub chain_id: ChainId,
pub requirements: Vec<String>,
}Expand description
The description of a service managed by the controller.
Fields
application_id: ApplicationIdThe application ID running the service (e.g. pm-engine)
name: StringThe role assumed by this service within the application (e.g. engine, event, market-maker).
chain_id: ChainIdThe chain on which the service is run. Note that this is different from the worker chains which typically only run the controller application for managing the worker itself.
requirements: Vec<String>The required capabilities for a worker to be useful (e.g. some API key). Concretely, the worker will read its environment variable